uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h
branchRCL_3
changeset 55 aecbbf00d063
parent 4 8ca85d2f0db7
child 56 d48ab3b357f1
--- a/uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h	Thu Aug 19 10:11:06 2010 +0300
+++ b/uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h	Tue Aug 31 15:28:30 2010 +0300
@@ -263,11 +263,11 @@
     TInt WorldHeight();
 
     /**
-     * Returns wheter pointer is in empty list area.
+     * Returns wheter pointer click is in empty list area.
      *
      * @return ETrue if aPosition is in empty list area.
      */    
-    TBool PointerOnEmptyArea( TPoint aPosition );
+    TBool EmptyAreaClicked( TPoint aPosition );
     
 private: // data
 
@@ -403,11 +403,10 @@
     // bottom item in current view, fields count when Y is larger than
     // the last item's Y
     TInt iOldBottomItem; 
-    
     /**
      * ETrue if pointer down on empty list area.
      */    
-    TBool iDownOnEmptyArea;
+    TBool iEmptyAreaClicked;
     };
@@ -403,11 +403,10 @@
     /**
-     * ETrue if pointer down on empty list area.
+     * ETrue if empty list area is clicked.
      */    